@@ -34,7 +34,7 @@
 static void usage();
 static int newimage = 0;
 static int verbose = 0;		/* verbose flag */
-static char *RevMsg = "ADDPIX WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "ADDPIX WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 static void AddPix();
 static int version = 0;		/* If 1, print only program name and version */
 
