@@ -66,7 +66,7 @@
 #define MST	3
 #define LST	4
 
-static char *RevMsg = "GETDATE WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "GETDATE WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 static void usage();
 static void ConvertDate();
