@@ -1,9 +1,9 @@
 /* File gethead.c
- * August 25, 2014
+ * January 20, 2015
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2014
+   Copyright (C) 1996-2015
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -47,7 +47,7 @@ extern char *GetFITShead();
 static char nextnsp();
 static int PrintValues();
 
-static char *RevMsg = "GETHEAD WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETHEAD WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int nfile = 0;
@@ -58,6 +58,7 @@ static int listpath = 0;
 static int j2000 = 0;		/* If 1, convert ra, dec keywords to J2000 */
 static int tabout = 0;
 static int tabpad = 0;
+static int tabchar = 0;		/* If 1, separate values by 1st keyward char */
 static int logfile = 0;
 static int printhead = 0;
 static int fillblank=0;		/* If 1, replace blanks in strings with _ */
@@ -221,6 +222,10 @@ char **av;
 		    listpath++;
 		    break;
 	
+		case 'r': /* Separate output values by single character */
+		    tabchar = 1;
+		    break;
+	
 		case 's': /* Do not pad output tab table */
 		    tabpad = 0;
 		    break;
@@ -1057,13 +1062,20 @@ char	*kwd[];		/* Names of keywords for which to print values */
 	    if (keyeqvaln)
 		printf ("%s = %s\n", keyword, str);
 	    else if (keyeqval) {
-		sprintf (temp, " %s=%s", keyword, str);
+		if (strchr (str,' '))
+		    sprintf (temp, "%s=\'%s\'", keyword, str);
+		else
+		    sprintf (temp, "%s=%s", keyword, str);
 		strcat (outline, temp);
 		}
 	    else if (verbose) {
 		sprintf (temp, " %s = %s", keyword, str);
 		strcat (outline, temp);
 		}
+	    else if (tabchar) {
+		sprintf (temp, "%c%s", keyword[0], str);
+		strcat (outline, temp);
+		}
 	    else
 		strcat (outline, str);
 	    nfound++;
@@ -1101,7 +1113,14 @@ char	*kwd[];		/* Names of keywords for which to print values */
 			    printf ("%s=%s\n", keyword, str);
 			}
 		    else if (keyeqval) {
-			sprintf (temp, " %s=%s", keyword, str);
+			if (strchr (str,' '))
+			    sprintf (temp, "%s=\'%s\'", keyword, str);
+			else
+			    sprintf (temp, "%s=%s", keyword, str);
+			strcat (outline, temp);
+			}
+		    else if (tabchar) {
+			sprintf (temp, "%c%s", keyword[0], str);
 			strcat (outline, temp);
 			}
 		    else {
@@ -1250,7 +1269,14 @@ char	*kwd[];		/* Names of keywords for which to print values */
 		    printf ("%s=%s\n", keyword, str);
 		}
 	    else if (keyeqval) {
-		sprintf (temp, " %s=%s", keyword, str);
+		if (strchr (str,' '))
+		    sprintf (temp, "%s=\'%s\'", keyword, str);
+		else
+		    sprintf (temp, "%s=%s", keyword, str);
+		strcat (outline, temp);
+		}
+	    else if (tabchar) {
+		sprintf (temp, "%c%s", keyword[0], str);
 		strcat (outline, temp);
 		}
 	    else if (strlen (str) < 1)
@@ -1277,7 +1303,10 @@ char	*kwd[];		/* Names of keywords for which to print values */
 			    printf ("%s.%s=%s\n", keyword, subkwd, string);
 			}
 		    else if (keyeqval) {
-			sprintf (temp, " %s=%s", keyword, string);
+			if (strchr (str,' '))
+			    sprintf (temp, "%s=\'%s\'", keyword, str);
+			else
+			    sprintf (temp, "%s=%s", keyword, str);
 			strcat (outline, temp);
 			}
 		    else
@@ -1303,7 +1332,10 @@ char	*kwd[];		/* Names of keywords for which to print values */
 		    printf ("%s=%s\n", keyword, mstring);
 		}
 	    else if (keyeqval) {
-		sprintf (temp, " %s=%s", keyword, mstring);
+		if (strchr (mstring, ' '))
+		    sprintf (temp, " %s=\'%s\'", keyword, mstring);
+		else
+		    sprintf (temp, " %s=%s", keyword, mstring);
 		strcat (outline, temp);
 		}
 	    else {
@@ -1322,7 +1354,7 @@ char	*kwd[];		/* Names of keywords for which to print values */
 	else
 	    notfound = 1;
 
-	if (!keyeqvaln && ikwd < nkwd-1) {
+	if (!keyeqvaln && !tabchar && ikwd < nkwd-1) {
 	    if (tabout)
 		strcat (outline, "	");
 	    else
@@ -1489,4 +1521,7 @@ char *string;
  * May  7 2014	Fix bug with unallocated extension
  * May 29 2014	Fix bugs dealing with freeing allocated memory
  * Aug 25 2014	Fix bug dealing with ranges of extensions
+ * Dec 19 2014	Add option to separate values by first character of keyword
+ *  
+ * Jan 20 2015	Add quotes to string values with spaces in -e option 
  */
