@@ -41,7 +41,7 @@ static void usage();
 static void PrintPix();
 static void procpix();
 
-static char *RevMsg = "GETPIX WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "GETPIX WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;		/* If 1, print only program name and version */
