@@ -34,7 +34,7 @@ static void usage();
 static void IRAFtoFITS ();
 
 static int verbose = 0;		/* verbose/debugging flag */
-static char *RevMsg = "I2F WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "I2F WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 static int version = 0;		/* If 1, print only program name and version */
 static int delirafkey = 0;	/* If 1, delete IRAF .imh keywords */
 static int deliraffile = 0;	/* If 1, delete IRAF .imh files */
