@@ -64,7 +64,7 @@ extern void setdateobs();
 extern void setparm();
 extern void setnpix();
 
-static char *RevMsg = "WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int wfile = 0;		/* True to print output file */
