@@ -39,7 +39,7 @@ static int nfiles = 0;		/* Nuber of files for headers */
 static int verbose = 0;		/* verbose/debugging flag */
 static int fitsout = 0;		/* If 1, write exact FITS header */
 static int zbitpix = 0;		/* If 1, set BITPIX to 0 for dataless header */
-static char *RevMsg = "IMHEAD WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "IMHEAD WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
 static int version = 0;		/* If 1, print only program name and version */
 
 int
