@@ -37,7 +37,7 @@ static int StackImage();
 static int verbose = 0;		/* verbose flag */
 static int wfits = 1;		/* if 1, write FITS header before data */
 static char *newname = NULL;
-static char *RevMsg = "IMSTACK WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMSTACK WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 static int nfiles = 0;
 static int nbstack = 0;
 static int extend = 0;		/* If 1, output multi-extension FITS file */
