@@ -28,7 +28,7 @@
 #include <string.h>
 #include "libwcs/fitshead.h"
 
-static char *RevMsg = "ISIMLIST WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "ISIMLIST WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
