@@ -36,7 +36,7 @@ static double matchrad = 5.0;	/* Initial match radius is 5 arcseconds */
 int version = 0;		/* If 1, print only program name and version */
 static void usage();
 
-static char *RevMsg = "MATCHCAT WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "MATCHCAT WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 main (ac, av)
 int ac;
