@@ -9,7 +9,7 @@
 #include "libned/ned_client.h"
 #include "libwcs/wcs.h"
 
-static char *RevMsg = "WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 extern int ned_errno;
 static void PrintUsage();
