@@ -10,7 +10,7 @@
 #include "libwcs/wcs.h"
 #include "libwcs/fitsfile.h"
 
-static char *RevMsg = "NEDPOS 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "NEDPOS 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 extern int ned_errno;
 static void PrintUsage();
