@@ -12,7 +12,7 @@
 
 extern int   ned_errno;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "SIMPOS 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 int
 main (ac, av)
