@@ -47,7 +47,7 @@ static int restwave = 0;	/* If 1, print first dimension limits */
 static int printhead = 1;	/* 1 until header has been printed */
 static char *rootdir=NULL;	/* Root directory for input files */
 
-static char *RevMsg = "WCSHEAD WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
+static char *RevMsg = "WCSHEAD WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
 
 int
 main (ac, av)
